# -*- coding: utf-8 -*-

"""Provides platforms."""

# https://docs.python.org/3.5/library/sys.html?highlight=sys#sys.platform
PLATFORMS = {
    "linux": {
        "home": "/home/",
    },
    "darwin": {
        "home": "/home/",
    },
    "win32": {
        "home": "C:\\Users\\",
    },
    "win64": {
        "home": "C:\\Users\\",
    },
}
