# -*- coding: utf-8 -*-

"""Here you can see data that used in all locales."""

from .address import *
from .code import *
from .common import *
from .datetime import *
from .development import *
from .file import *
from .finance import *
from .hardware import *
from .internet import *
from .path import *
from .payment import *
from .person import *
from .scientific import *
from .text import *
from .transport import *
