# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['mimesis',
 'mimesis.builtins',
 'mimesis.data',
 'mimesis.data.int',
 'mimesis.providers']

package_data = \
{'': ['*'],
 'mimesis.data': ['bin/*',
                  'cs/*',
                  'da/*',
                  'de-at/*',
                  'de-ch/*',
                  'de/*',
                  'el/*',
                  'en-au/*',
                  'en-ca/*',
                  'en-gb/*',
                  'en/*',
                  'es-mx/*',
                  'es/*',
                  'et/*',
                  'fa/*',
                  'fi/*',
                  'fr/*',
                  'hu/*',
                  'is/*',
                  'it/*',
                  'ja/*',
                  'kk/*',
                  'ko/*',
                  'nl-be/*',
                  'nl/*',
                  'no/*',
                  'pl/*',
                  'pt-br/*',
                  'pt/*',
                  'ru/*',
                  'sk/*',
                  'sv/*',
                  'tr/*',
                  'uk/*',
                  'zh/*']}

setup_kwargs = {
    'name': 'mimesis',
    'version': '5.0.0',
    'description': 'Mimesis: fake data generator.',
    'long_description': "Mimesis - Fake Data Generator\n-----------------------------\n\n|\n\n.. image:: https://raw.githubusercontent.com/lk-geimfari/mimesis/master/.github/images/octopus-no-retina-sm.png\n     :target: https://github.com/lk-geimfari/mimesis\n\n|\n\nDescription\n-----------\n\n.. image:: https://github.com/lk-geimfari/mimesis/actions/workflows/test.yml/badge.svg?branch=master\n     :target: https://github.com/lk-geimfari/mimesis/actions/workflows/test.yml?query=branch%3Amaster\n     :alt: Github Actions Test\n\n.. image:: https://readthedocs.org/projects/mimesis/badge/?version=latest\n     :target: https://mimesis.name/\n     :alt: Documentation Status\n\n.. image:: https://codecov.io/gh/lk-geimfari/mimesis/branch/master/graph/badge.svg\n     :target: https://codecov.io/gh/lk-geimfari/mimesis\n     :alt: Code Coverage\n\n.. image:: https://www.codefactor.io/repository/github/lk-geimfari/mimesis/badge\n   :target: https://www.codefactor.io/repository/github/lk-geimfari/mimesis\n   :alt: CodeFactor\n\n.. image:: https://img.shields.io/pypi/v/mimesis?color=bright-green\n     :target: https://pypi.org/project/mimesis/\n     :alt: PyPi Version\n\n.. image:: https://img.shields.io/pypi/dm/mimesis\n     :target: https://pypi.org/project/mimesis/\n     :alt: PyPI - Downloads\n\n.. image:: https://img.shields.io/badge/python-3.8%20%7C%203.9-brightgreen\n     :target: https://pypi.org/project/mimesis/\n     :alt: Python version\n\nMimesis (/mɪˈmiːsɪs, Ancient Greek: μίμησις, mīmēsis) is a high-performance fake data generator for Python,\nwhich provides data for a variety of purposes in a variety of languages. The fake data could be used to populate\na testing database, create fake API endpoints, create JSON and XML files of arbitrary structure, anonymize data taken\nfrom production and etc.\n\nInstallation\n------------\n\n\nTo install mimesis, simply use pip:\n\n.. code:: text\n\n    ~ ⟩ pip install mimesis\n\n\nPython compatibility\n---------------------\n\nMimesis 5.0 supports Python 3.8, 3.9, and 3.10.\n\nThe Mimesis 4.1.3 is the last to support Python 3.6 and 3.7.\n\nSupported Features\n------------------\n\n- **Easy**: Designed to be easy to use and learn.\n- **Multilingual**: Supports data for `a lot of languages <https://mimesis.name/getting_started.html#locales>`_.\n- **Performance**: The `fastest <https://mimesis.name/foreword.html#performance>`_ data generator available for Python.\n- **Data variety**: Supports `a lot of data providers <https://mimesis.name/api.html>`_ for a variety of purposes.\n- **Country-specific data providers**: Provides data specific only for `some countries <https://mimesis.name/api.html#builtin-data-providers>`_.\n- **Extensibility**: You can create your own data providers and use them with Mimesis.\n- **Generic data provider**: The `simplified <https://mimesis.name/getting_started.html#generic-provider>`_ access to all the providers from a single object.\n- **Zero hard dependencies**: Does not require any modules other than the Python standard library.\n- **Schema-based generators**: Provides an easy mechanism to generate data by the schema of any complexity.\n\n\nDocumentation\n-------------\n\nYou can find the complete documentation on the `Read the Docs <https://mimesis.name>`_.\n\nIt is divided into several sections:\n\n-  `Foreword <https://mimesis.name/foreword.html>`_\n-  `Getting Started <https://mimesis.name/getting_started.html>`_\n-  `Tips and Tricks <https://mimesis.name/tips.html>`_\n-  `API Reference <https://mimesis.name/api.html>`_\n-  `Contributing <https://mimesis.name/contributing.html>`_\n-  `Changelog <https://mimesis.name/changelog.html>`_\n\nYou can improve it by sending pull requests to this repository.\n\nUsage\n-----\n\nThis readme file contains information for Mimesis 5.0.0 which is not released yet, so If you're \nlooking for actual docs for 4.1.3 then see: https://mimesis.name/\n\nThis library is really easy to use and everything you need is just import an object which\nrepresents a type of data you need (we call such object a *Provider*).\n\nIn the example below we import provider `Person <https://mimesis.name/api.html#person>`_,\nwhich represents data related to personal information, such as name, surname, email and etc:\n\n.. code:: python\n\n    >>> from mimesis import Person\n    >>> from mimesis.locales import Locale\n    >>> person = Person(Locale.EN)\n\n    >>> person.full_name()\n    'Brande Sears'\n\n    >>> person.email(domains=['example.com'])\n    'roccelline1878@example.com'\n\n    >>> person.email(domains=['mimesis.name'], unique=True)\n    'f272a05d39ec46fdac5be4ac7be45f3f@mimesis.name'\n\n    >>> person.telephone(mask='1-4##-8##-5##3')\n    '1-436-896-5213'\n\n\nMore about the other providers you can read in our `documentation`_.\n\n.. _documentation: https://mimesis.name/getting_started.html#providers\n\n\nLocales\n-------\n\nMimesis currently includes support for 34 different `locales`_. You can\nspecify a locale when creating providers and they will return data that\nis appropriate for the language or country associated with that locale.\n\nLet's take a look how it works:\n\n.. code:: python\n\n    >>> from mimesis import Person\n    >>> from mimesis.locales import Locale\n    >>> from mimesis.enums import Gender\n\n    >>> de = Person(locale=Locale.DE)\n    >>> en = Person(locale=Locale.EN)\n\n    >>> de.full_name(gender=Gender.FEMALE)\n    'Sabrina Gutermuth'\n\n    >>> en.full_name(gender=Gender.MALE)\n    'Layne Gallagher'\n\n\n.. _locales: https://mimesis.name/getting_started.html#locales\n\nProviders\n---------\n\nMimesis support over twenty different data providers available,\nwhich can produce data related to people, food, computer hardware,\ntransportation, addresses, internet and more.\n\nSee `Data Providers <https://mimesis.name/getting_started.html#data-providers>`_ for more info.\n\nHow to Contribute\n-----------------\n\n1. Take a look at `contributing guidelines`_.\n2. Check for open issues or open a fresh issue to start a discussion\n   around a feature idea or a bug.\n3. Fork the repository on GitHub to start making your changes to the\n   *your_branch* branch.\n4. Add yourself to the list of `contributors`_.\n5. Send a pull request and bug the maintainer until it gets merged and\n   published.\n\n.. _contributing guidelines: https://github.com/lk-geimfari/mimesis/blob/master/CONTRIBUTING.rst\n.. _contributors: https://github.com/lk-geimfari/mimesis/blob/master/CONTRIBUTORS.rst\n\n\nUseful links\n------------\n\nI have a Telegram channel where I daily post news, announces and all the open-source\ngoodies I found, so subscribe: `@software_dev_channel <https://t.me/software_dev_channel>`_.\n\nDisclaimer\n----------\n\nThe authors of `Mimesis` do not assume any responsibility for how you use it or how you use data generated with it.\nThis library was designed with good intentions to make testing easier. Do not use the data generated with Mimesis for illegal purposes.\n\nLicense\n-------\n\nMimesis is licensed under the MIT License. See `LICENSE`_ for more\ninformation.\n\n.. _LICENSE: https://github.com/lk-geimfari/mimesis/blob/master/LICENSE\n",
    'author': 'Isaak Uchakaev',
    'author_email': 'likid.geimfari@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/lk-geimfari/mimesis',
    'packages': packages,
    'package_data': package_data,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
