# -*- coding: utf-8 -*-

"""Provides all the data related to science."""

SI_PREFIXES = {
    "negative": [
        "deci",
        "centi",
        "milli",
        "micro",
        "nano",
        "pico",
        "femto",
        "atto",
        "zepto",
        "yocto",
    ],
    "positive": [
        "yotta",
        "zetta",
        "exa",
        "peta",
        "tera",
        "giga",
        "mega",
        "kilo",
        "hecto",
        "deca",
    ],
}

SI_PREFIXES_SYM = {
    "negative": ["d", "c", "m", "μ", "n", "p", "f", "a", "z", "y"],
    "positive": ["Y", "Z", "E", "P", "T", "G", "M", "k", "h", "da"],
}
