# -*- coding: utf-8 -*-

"""Provides all the data related to the development."""

LICENSES = [
    "Apache License, 2.0 (Apache-2.0)",
    "The BSD 3-Clause License",
    "The BSD 2-Clause License",
    "GNU General Public License (GPL)",
    "General Public License (LGPL)",
    "MIT License (MIT)",
    "Mozilla Public License 2.0 (MPL-2.0)",
    "Common Development and Distribution License (CDDL-1.0)",
    "Eclipse Public License (EPL-1.0)",
]

PROGRAMMING_LANGS = [
    "ASP",
    "Assembly",
    "AutoIt",
    "Awk",
    "Bash",
    "C",
    "C Shell",
    "C#",
    "C++",
    "Caml",
    "Ceylon",
    "Clojure",
    "CoffeeScript",
    "Common Lisp",
    "D",
    "Dart",
    "Delphi",
    "Dylan",
    "ECMAScript",
    "Elixir",
    "Emacs Lisp",
    "Erlang",
    "F#",
    "Falcon",
    "Fortran",
    "GNU Octave",
    "Go",
    "Groovy",
    "Haskell",
    "haXe",
    "Io",
    "J#",
    "Java",
    "JavaScript",
    "Julia",
    "Kotlin",
    "Lisp",
    "Lua",
    "Mathematica",
    "Objective-C",
    "OCaml",
    "Perl",
    "PHP",
    "PL-I",
    "PL-SQL",
    "PowerShell",
    "Prolog",
    "Python",
    "R",
    "Racket",
    "Ruby",
    "Rust",
    "Scala",
    "Scheme",
    "Smalltalk",
    "Tcl",
    "Tex",
    "Transact-SQL",
    "TypeScript",
    "Z shell",
]

OS = [
    "Arch",
    "CentOS",
    "Debian",
    "Fedora",
    "FreeBSD",
    "Gentoo",
    "Kali",
    "Lubuntu",
    "Manjaro",
    "Mint",
    "OS X",
    "macOS",
    "OpenBSD",
    "PCLinuxOS",
    "Slackware",
    "Ubuntu",
    "Windows 10",
    "Windows 7",
    "Windows 8",
    "Windows 8.1",
    "Zorin",
    "elementaryOS",
    "macOS",
    "openSUSE",
]

FOLDERS = [
    "Development",
    "Downloads",
    "Documents",
    "Music",
    "Video",
    "Work",
    "Pictures",
    "Desktop",
    "Study",
]

PROJECT_NAMES = [
    "aardonyx",
    "abelisaurus",
    "achelousaurus",
    "achillobator",
    "acrocanthosaurus",
    "aegyptosaurus",
    "afrovenator",
    "agilisaurus",
    "alamosaurus",
    "albertaceratops",
    "albertosaurus",
    "alectrosaurus",
    "alioramus",
    "allosaurus",
    "alvarezsaurus",
    "amargasaurus",
    "ammosaurus",
    "ampelosaurus",
    "amygdalodon",
    "anatotitan",
    "anchiceratops",
    "anchisaurus",
    "ankylosaurus",
    "anserimimus",
    "antarctopelta",
    "antarctosaurus",
    "apatosaurus",
    "aragosaurus",
    "aralosaurus",
    "archaeoceratops",
    "archaeopteryx",
    "archaeornithomimus",
    "argentinosaurus",
    "arrhinoceratops",
    "atlascopcosaurus",
    "aucasaurus",
    "austrosaurus",
    "avaceratops",
    "avalonia",
    "avimimus",
    "azendohsaurus",
    "bactrosaurus",
    "bagaceratops",
    "bambiraptor",
    "barapasaurus",
    "barosaurus",
    "baryonyx",
    "becklespinax",
    "beipiaosaurus",
    "bellusaurus",
    "borogovia",
    "brachiosaurus",
    "brachyceratops",
    "bugenasaura",
    "buitreraptor",
    "camarasaurus",
    "camptosaurus",
    "carnotaurus",
    "caudipteryx",
    "cedarpelta",
    "centrosaurus",
    "ceratosaurus",
    "cetiosauriscus",
    "cetiosaurus",
    "chaoyangsaurus",
    "chasmosaurus",
    "chialingosaurus",
    "chindesaurus",
    "chinshakiangosaurus",
    "chirostenotes",
    "chubutisaurus",
    "chungkingosaurus",
    "citipati",
    "coelophysis",
    "coelurus",
    "coloradisaurus",
    "compsognathus",
    "conchoraptor",
    "confuciusornis",
    "corythosaurus",
    "cryolophosaurus",
    "dacentrurus",
    "daspletosaurus",
    "datousaurus",
    "deinocheirus",
    "deinonychus",
    "deltadromeus",
    "diceratops",
    "dicraeosaurus",
    "dilophosaurus",
    "diplodocus",
    "dracorex",
    "dravidosaurus",
    "dromaeosaurus",
    "dromiceiomimus",
    "dryosaurus",
    "dryptosaurus",
    "dubreuillosaurus",
    "edmontonia",
    "edmontosaurus",
    "einiosaurus",
    "elaphrosaurus",
    "emausaurus",
    "eolambia",
    "eoraptor",
    "eotyrannus",
    "equijubus",
    "erketu",
    "erlikosaurus",
    "euhelopus",
    "euoplocephalus",
    "europasaurus",
    "euskelosaurus",
    "eustreptospondylus",
    "fukuiraptor",
    "fukuisaurus",
    "gallimimus",
    "gargoyleosaurus",
    "garudimimus",
    "gasosaurus",
    "gasparinisaura",
    "gastonia",
    "giganotosaurus",
    "gilmoreosaurus",
    "giraffatitan",
    "gobisaurus",
    "gorgosaurus",
    "goyocephale",
    "graciliceratops",
    "gryposaurus",
    "guaibasaurus",
    "guanlong",
    "hadrosaurus",
    "hagryphus",
    "haplocanthosaurus",
    "harpymimus",
    "herrerasaurus",
    "hesperosaurus",
    "heterodontosaurus",
    "homalocephale",
    "huayangosaurus",
    "hylaeosaurus",
    "hypacrosaurus",
    "hypselosaurus",
    "hypsilophodon",
    "iguanodon",
    "indosuchus",
    "ingenia",
    "irritator",
    "isisaurus",
    "janenschia",
    "jaxartosaurus",
    "jingshanosaurus",
    "jinzhousaurus",
    "jobaria",
    "juravenator",
    "kentrosaurus",
    "khaan",
    "kotasaurus",
    "kritosaurus",
    "lamaceratops",
    "lambeosaurus",
    "lapparentosaurus",
    "leaellynasaura",
    "leptoceratops",
    "lesothosaurus",
    "lexovisaurus",
    "liaoceratops",
    "liaoxiornis",
    "ligabuesaurus",
    "liliensternus",
    "lophorhothon",
    "lophostropheus",
    "lufengosaurus",
    "lurdusaurus",
    "lycorhinus",
    "magyarosaurus",
    "maiasaura",
    "majungatholus",
    "malawisaurus",
    "mamenchisaurus",
    "mapusaurus",
    "marshosaurus",
    "masiakasaurus",
    "massospondylus",
    "maxakalisaurus",
    "megalosaurus",
    "melanorosaurus",
    "metriacanthosaurus",
    "microceratops",
    "micropachycephalosaurus",
    "microraptor",
    "minmi",
    "monolophosaurus",
    "mononykus",
    "mussaurus",
    "muttaburrasaurus",
    "nanotyrannus",
    "nanshiungosaurus",
    "nemegtosaurus",
    "neovenator",
    "neuquenosaurus",
    "nigersaurus",
    "nipponosaurus",
    "noasaurus",
    "nodosaurus",
    "nomingia",
    "nothronychus",
    "nqwebasaurus",
    "omeisaurus",
    "ornitholestes",
    "ornithomimus",
    "orodromeus",
    "oryctodromeus",
    "othnielia",
    "ouranosaurus",
    "oviraptor",
    "rebbachisaurus",
    "rhabdodon",
    "rhoetosaurus",
    "rinchenia",
    "riojasaurus",
    "rugops",
    "saichania",
    "saltasaurus",
    "saltopus",
    "sarcosaurus",
    "saurolophus",
    "sauropelta",
    "saurophaganax",
    "saurornithoides",
    "scelidosaurus",
    "scutellosaurus",
    "secernosaurus",
    "segisaurus",
    "segnosaurus",
    "seismosaurus",
    "shamosaurus",
    "shanag",
    "shantungosaurus",
    "shunosaurus",
    "shuvuuia",
    "silvisaurus",
    "sinocalliopteryx",
    "sinornithosaurus",
    "sinosauropteryx",
    "sinraptor",
    "sinvenator",
    "zalmoxes",
    "zephyrosaurus",
    "zuniceratops",
    "byzantine",
    "svengali",
    "accolade",
    "acrimony",
    "angst",
    "anomaly",
    "antidote",
    "baroque",
    "bona_fide",
    "bourgeois",
    "bravado",
    "brogue",
    "brusque",
    "cacophony",
    "caustic",
    "charisma",
    "cloying",
    "deja-vu",
    "dichotomy",
    "elan",
    "ennui",
    "epitome",
    "esoteric",
    "euphemism",
    "faux pas",
    "fiasco",
    "finagle",
    "glib",
    "harbinger",
    "hedonist",
    "heresy",
    "idyllic",
    "insidious",
    "junket",
    "kitsch",
    "litany",
    "lurid",
    "malaise",
    "malinger",
    "mantra",
    "maudlin",
    "mercenary",
    "misnomer",
    "nirvana",
    "oblivion",
    "ogle",
    "ostracize",
    "panacea",
    "paradox",
    "peevish",
    "propriety",
    "revel",
    "rhetoric",
    "spartan",
    "stigma",
    "stoic",
    "suave",
    "sycophant",
    "tirade",
    "tryst",
    "untenable",
    "vicarious",
    "vile",
    "waft",
    "zealous",
]
